@@ -24,7 +24,7 @@ __PACKAGE__->result_source_instance->view_definition(<<ENDSQL
     WHERE action IN ( 'discover', 'macsuck', 'arpnip', 'nbtstat' ) 
     GROUP BY action, entered 
     HAVING count( device ) > 1
-      AND SUM( CASE WHEN status LIKE 'queued%' THEN 1 ELSE 0 END ) = 0
+      AND SUM( CASE WHEN status = 'queued' THEN 1 ELSE 0 END ) = 0
     ORDER BY entered DESC, elapsed DESC
     LIMIT 30
 ENDSQL
