@@ -44,7 +44,7 @@ ajax '/ajax/data/device/:ip/snmptree/:base' => require_login sub {
     }] unless $device->oids->count;
 
     return to_json [{
-      text => 'No MIB data. Please run `~/bin/netdisco-do loadmibs`.',
+      text => 'No MIB objects. Please run a loadmibs job.',
       children => \0,
       state => { disabled => \1 },
       icon => 'icon-search',
